//---------------------------------------------------------------------------
//
//                     XMM Science Analysis System (SAS)
//                    (c) 1997-2010 European Space Agency
//
//---------------------------------------------------------------------------
//
//      checkpn_burst.cc: --- test harness for epproc
//
//
//      CHANGE HISTORY:
//           AI, 2004-06-07: 1.0.0: - first version
//
//      REFERENCES:
//
//      AUTHOR:
//           A. Ibarra (AI), Mon Jun  7 11:39:01 CEST 2004
//
//      COMMENTS:
//           Due to problems with DAL and MacOS, we have had to change the test harness
//           for epproc package. The old test harness programs were written in perl, now
//           the test harness programs have been recoded in C++.
//     
//

#include <iostream>
#include <Dal.h>
#include <cassert>
#include <string>
#include <vector>
#include <cmath>

int main (int argc, char* argv[])
{

  if (argc != 2 )
    {
      std::cerr<<"Usage: "<<argv[0]<<" <expr> \n";
      return 1;
    }
  
  std::vector <std::string>  tables;
  tables.push_back("EVENTS");
  tables.push_back("EXPOSU04");
  tables.push_back("BADPIX04");
  tables.push_back("STDGTI04");
  tables.push_back("CALINDEX");

  std::vector < std::string> columns;
  columns.push_back("TIME");
  columns.push_back("RAWX");
  columns.push_back("RAWY");
  columns.push_back("PHA");
  columns.push_back("PI");
  columns.push_back("FLAG");
  columns.push_back("PATTERN");
  columns.push_back("PAT_ID");
  columns.push_back("CCDNR");


  std::string name(argv[1]);
  DataSet* set = dataSetServer->open(name, Dal::Read);

  for (unsigned i=0; i<tables.size() ; i++)
    {      
      if( set->table(tables[i]) )
	std::cout << tables[i] << std::endl; 
      else
	{
	  std::cerr << "table: " << tables[i] << " missing " << std::endl;
	  return 1;
	}
    }

  Table* tab = set->table("EVENTS"); 

  for (unsigned i=0; i<columns.size() ; i++)
    {      
      if( tab->column(columns[i]) )
	std::cout << columns[i] << std::endl; 
      else
	{
	  std::cerr << "column: " << columns[i] << " missing " << std::endl;
	  return 1;
	}
    }
  

  int numberEvents =  tab->rows();
  std::cout << "EVENTS " <<  numberEvents <<std::endl;
  
  double numRef = 5745;
  double numRefHigh = numRef + sqrt(numRef);
  double numRefLow = numRef - sqrt(numRef);
  
  assert((numRef > numRefLow) && (numRef < numRefHigh) );
  tab->release();


  tab = set->table("EXPOSU04");
  std::cout << "EXPOSU04 " << tab->rows() << std::endl;
  assert(tab->rows() == 920285 ); 
  tab->release();

  tab = set->table("STDGTI04");
  std::cout << "STDGTI04 " << tab->rows() << std::endl;
  assert(tab->rows() == 3 );  
  tab->release();

  // Due to the continuous changes in the CALINDEX table,
  // we have removed this check (05/10/04)
  /*
    tab = set->table("CALINDEX");
    std::cout << "CALINDEX " << tab->rows() << std::endl;
    assert(tab->rows() == 101);
    tab->release();
  */

  dataSetServer->close(set);  
  return 0;
}
